import sys
import logging

LOG_FORMAT_HEADER = "[%(asctime)s][%(levelname)7s]"
LOG_FORMAT = LOG_FORMAT_HEADER + " %(message)s"


def create_shell_logging_config(
    level=logging.INFO, format: str = LOG_FORMAT, handler_class: str = "airflow_db_logger.handlers.StreamHandler"
):
    return {
        "version": 1,
        "disable_existing_loggers": False,
        "formatters": {
            "shell": {"format": LOG_FORMAT},
        },
        "handlers": {
            "console": {
                "class": handler_class,
                "formatter": "shell",
            },
            "task": {
                "class": handler_class,
                "formatter": "shell",
            },
            "processor": {
                "class": handler_class,
                "formatter": "shell",
            },
        },
        "loggers": {
            "airflow.processor": {
                "handlers": ["processor"],
                "level": level,
                "propagate": False,
            },
            "airflow.task": {
                "handlers": ["task"],
                "level": level,
                "propagate": False,
            },
            "flask_appbuilder": {
                "handler": ["console"],
                "level": level,
                "propagate": True,
            },
        },
        "root": {
            "handlers": ["console"],
            "level": level,
        },
    }


SIMPLE_LOGGING_CONFIG = create_shell_logging_config(logging.INFO, handler_class="logging.StreamHandler")
LOGGING_CONFIG = create_shell_logging_config(logging.INFO)



import os
from copy import deepcopy
from airflow_db_logger.shell_logging_config import create_shell_logging_config

global IS_DB_LOGGER_LOADING_CONFIG
IS_DB_LOGGER_LOADING_CONFIG = False

global DB_LOGGER_LOGGING_CONFIG
DB_LOGGER_LOGGING_CONFIG = create_shell_logging_config()


def get_default_loggin_config():
    from airflow.version import version as AIRFLOW_VERSION

    AIRFLOW_VERSION_PARTS = AIRFLOW_VERSION.split(".")
    AIRFLOW_VERSION_PARTS = [int(v) for v in AIRFLOW_VERSION_PARTS]

    AIRFLOW_MAJOR_VERSION = AIRFLOW_VERSION_PARTS[0]

    """Returns the airflow default logging config from the settings.

    Start the ariflow system. settings.initialize should be called if the logging configuration is to be reset?
    """

    config_env_name = (
        "AIRFLOW__LOGGING__LOGGING_CONFIG_CLASS" if AIRFLOW_MAJOR_VERSION > 1 else "AIRFLOW__CORE__LOGGING_CONFIG_CLASS"
    )

    action_logging_config_env = os.environ.get(config_env_name, None)

    os.environ[config_env_name] = "airflow_db_logger.shell_logging_config.SIMPLE_LOGGING_CONFIG"

    from airflow.config_templates.airflow_local_settings import DEFAULT_LOGGING_CONFIG  # noqa

    if action_logging_config_env is not None:
        os.environ[config_env_name] = action_logging_config_env

    return DEFAULT_LOGGING_CONFIG



#!/usr/bin/env python
# -*- coding: utf-8 -*-
__title__ = "airflow_db_logger"
__author__ = "Zav Shotan"

import sys
import os
from copy import deepcopy
import airflow_db_logger.consts as consts


LOGGING_CONFIG = consts.DB_LOGGER_LOGGING_CONFIG
AIRFLOW_DEFAULT_LOGGING_CONFIG = consts.get_default_loggin_config()

from airflow_db_logger.config import (  # noqa
    check_cli_for_init_db,  # noqa: E402
    DB_LOGGER_TASK_FORMATTER,  # noqa: E402
    DB_LOGGER_CONSOLE_FORMATTER,  # noqa: E402
    DB_LOGGER_WRITE_DAG_PROCESSING_TO_DB,  # noqa: E402
    DB_LOGGER_PROCESSER_LOG_LEVEL,
    airflow_db_logger_log,
)


def update_config_from_defaults():
    consts.IS_DB_LOGGER_LOADING_CONFIG

    if consts.IS_DB_LOGGER_LOADING_CONFIG is True:
        return

    # Remove any other loads.
    try:
        consts.IS_DB_LOGGER_LOADING_CONFIG = True

        processor_handler_config = {
            "class": "airflow_db_logger.handlers.StreamHandler",
            "formatter": DB_LOGGER_CONSOLE_FORMATTER,
            "level": DB_LOGGER_PROCESSER_LOG_LEVEL,
        }

        if DB_LOGGER_WRITE_DAG_PROCESSING_TO_DB:
            processor_handler_config = {
                "class": "airflow_db_logger.handlers.DBProcessLogHandler",
                "formatter": DB_LOGGER_CONSOLE_FORMATTER,
                "level": DB_LOGGER_PROCESSER_LOG_LEVEL,
            }

        LOGGING_CONFIG.update(deepcopy(AIRFLOW_DEFAULT_LOGGING_CONFIG))
        LOGGING_CONFIG["handlers"] = {
            "console": {
                "class": "airflow_db_logger.handlers.StreamHandler",
                "formatter": DB_LOGGER_CONSOLE_FORMATTER,
            },
            "task": {
                "class": "airflow_db_logger.handlers.DBTaskLogHandler",
                "formatter": DB_LOGGER_TASK_FORMATTER,
            },
            "processor": processor_handler_config,
        }

        loggers = LOGGING_CONFIG.get("loggers", {})

        # for logger_name in loggers.keys():
        #     loggers[logger_name]["level"] = LOG_LEVEL

        # Checking for database initialization
        check_cli_for_init_db()

    finally:
        consts.IS_DB_LOGGER_LOADING_CONFIG = False


update_config_from_defaults()
# airflow_db_logger_log.info("airflow_db_logger initialized")



from datetime import datetime
from typing import Any
from sqlalchemy.orm import Session, Query

from airflow.utils.log.logging_mixin import LoggingMixin
from airflow.models import BaseOperator
from airflow_db_logger.config import AIRFLOW_MAJOR_VERSION
from airflow_db_logger.exceptions import DBLoggerException
from airflow_db_logger.data import DagFileProcessingLogRecord, TaskExecutionLogRecord, LoggerModelBase

if AIRFLOW_MAJOR_VERSION > 1:
    from airflow.utils.session import provide_session
else:
    from airflow.utils.db import provide_session


class AirflowDBLoggerCleanupOperator(BaseOperator, LoggingMixin):
    def __init__(
        self,
        task_id: str,
        up_to: datetime,
        since: datetime = None,
        include_task_logs=True,
        include_operations_log=True,
        **kwargs,
    ) -> None:
        assert isinstance(up_to, datetime), ValueError("up_to must be of type datetime")

        super().__init__(task_id=task_id, **kwargs)

        assert include_operations_log or include_task_logs, ValueError(
            "Either include_operations_log or include_task_logs must be true"
        )

        self.upto = up_to
        self.since = since
        self.include_task_logs = include_task_logs
        self.include_operations_log = include_operations_log

    @provide_session
    def execute(self, session: Session, context: Any):
        """
        Executes the cleanup command.
        """

        since = self.since if self.since is not None else "Beginning of time"
        upto = self.upto

        if self.include_operations_log:
            self.log.info(f"operations logs: Deleting from {since} -> {upto}")
            query: Query = session.query(DagFileProcessingLogRecord)
            query = query.filter(DagFileProcessingLogRecord.timestamp < self.upto)
            if self.since:
                query = query.filter(DagFileProcessingLogRecord.timestamp >= self.since)

            delete_count = query.delete()
            query.session.commit()
            self.log.info(f"operations logs: Deleted {delete_count} records")

        if self.include_task_logs:
            self.log.info(f"Task logs: Deleting from {since} -> {upto}")
            query: Query = session.query(TaskExecutionLogRecord)
            query = query.filter(TaskExecutionLogRecord.timestamp < self.upto)
            if self.since:
                query = query.filter(TaskExecutionLogRecord.timestamp >= self.since)

            delete_count = query.delete()
            query.session.commit()
            self.log.info(f"Task logs: Deleted {delete_count} records")

        self.log.info("Cleanup complete")
